const fs = require("fs").promises;
const UglifyJS = require("uglify-js");
const path = require("path");

// 输入目录，修改为你要压缩和混淆的文件所在目录
const inputDirectory = "js";
// 输出目录，修改为你想要存储压缩和混淆文件的目录
const outputDirectory = "dist";

async function compressObfuscateDirectory() {
  try {
    // 确保输出目录存在，如果不存在则创建
    try {
      await fs.access(outputDirectory);
    } catch (err) {
      await fs.mkdir(outputDirectory, { recursive: true });
    }

    const files = await fs.readdir(inputDirectory);
    for (const file of files) {
      const inputFilePath = path.join(inputDirectory, file);
      const outputFilePath = path.join(outputDirectory, file);
      // 仅处理.js 文件
      if (path.extname(file) === ".js") {
        const stats = await fs.stat(inputFilePath);
        if (stats.isFile()) {
          const data = await fs.readFile(inputFilePath, "utf8");
          // 使用 UglifyJS 进行压缩和混淆
          const result = UglifyJS.minify(data, {
            mangle: true, // 启用混淆
            compress: {
              sequences: true, // 优化代码中连续的语句
              dead_code: true, // 删除不可达代码
              conditionals: true, // 优化条件表达式
              booleans: true, // 优化布尔表达式
              unused: true, // 移除未使用的变量和函数
              if_return: true, // 优化 if 语句的返回值
              join_vars: true, // 合并变量声明
              drop_console: false, // 移除 console 语句（可根据需要开启或关闭）
            },
          });
          if (result.error) {
            console.error(
              `Error compressing and obfuscating file ${file}:`,
              result.error
            );
            continue;
          }
          await fs.writeFile(outputFilePath, result.code);
          console.log(`File ${file} compressed and obfuscated successfully.`);
        }
      }
    }
  } catch (err) {
    console.error("Error during compression and obfuscation:", err);
  }
}

compressObfuscateDirectory();
